@@ -16,14 +16,14 @@ GPIO16 = Pin(16)
 TOUT = Pin("TOUT")
 
 # ordered as spiId, sckId, mosiId, misoId
-SPI_PORTS = (1, GPIO14, GPIO13, GPIO12)
+spiPorts = (1, GPIO14, GPIO13, GPIO12)
 
 # ordered as uartId, txId, rxId
-UART_PORTS = (
+uartPorts = (
     (0, GPIO1, GPIO3),
     # TODO secondary pins for UART0 configurable from Micropython? How to flag?
     # (0, GPIO15, GPIO13)
     (1, GPIO2, None),
 )
 
-I2C_PORTS = ()
+i2cPorts = ()
