@@ -44,6 +44,9 @@ elif board_id == ap_board.NODEMCU:
 elif board_id == ap_board.PYBOARD:
     from adafruit_blinka.board.pyboard import *
 
+elif board_id == ap_board.RASPBERRY_PI_PICO:
+    from adafruit_blinka.board.raspberrypi.pico import *
+
 elif detector.board.any_raspberry_pi_40_pin:
     from adafruit_blinka.board.raspberrypi.raspi_40pin import *
 
@@ -56,6 +59,9 @@ elif detector.board.RASPBERRY_PI_B_REV1:
 elif detector.board.RASPBERRY_PI_A or detector.board.RASPBERRY_PI_B_REV2:
     from adafruit_blinka.board.raspberrypi.raspi_1b_rev2 import *
 
+elif board_id == ap_board.BEAGLEBONE:
+    from adafruit_blinka.board.beagleboard.beaglebone_black import *
+
 elif board_id == ap_board.BEAGLEBONE_BLACK:
     from adafruit_blinka.board.beagleboard.beaglebone_black import *
 
@@ -122,6 +128,9 @@ elif board_id == ap_board.JETSON_TX1:
 elif board_id == ap_board.JETSON_TX2:
     from adafruit_blinka.board.nvidia.jetson_tx2 import *
 
+elif board_id == ap_board.JETSON_TX2_NX:
+    from adafruit_blinka.board.nvidia.jetson_tx2_nx import *
+
 elif board_id == ap_board.JETSON_XAVIER:
     from adafruit_blinka.board.nvidia.jetson_xavier import *
 
@@ -188,6 +197,12 @@ elif board_id == ap_board.ONION_OMEGA2:
 elif board_id == ap_board.ROCK_PI_S:
     from adafruit_blinka.board.radxa.rockpis import *
 
+elif board_id == ap_board.ROCK_PI_4:
+    from adafruit_blinka.board.radxa.rockpi4 import *
+
+elif board_id == ap_board.ROCK_PI_E:
+    from adafruit_blinka.board.radxa.rockpie import *
+
 elif board_id == ap_board.UDOO_X86:
     from adafruit_blinka.board.udoo_x86ultra import *
 
@@ -197,28 +212,50 @@ elif board_id == ap_board.STM32MP157C_DK2:
 elif board_id == ap_board.LUBANCAT_IMX6ULL:
     from adafruit_blinka.board.lubancat.lubancat_imx6ull import *
 
+elif board_id == ap_board.LUBANCAT_STM32MP157:
+    from adafruit_blinka.board.lubancat.lubancat_stm32mp157 import *
+
 elif board_id == ap_board.NANOPI_NEO_AIR:
     from adafruit_blinka.board.nanopi.neoair import *
 
 elif board_id == ap_board.NANOPI_DUO2:
     from adafruit_blinka.board.nanopi.duo2 import *
 
+elif board_id == ap_board.PICO_U2IF:
+    from adafruit_blinka.board.pico_u2if import *
+
 elif "sphinx" in sys.modules:
     pass
 
+elif board_id is None:
+    import platform
+    import pkg_resources
+
+    package = str(pkg_resources.get_distribution("adafruit_platformdetect")).split()
+    raise NotImplementedError(
+        "{1} version {2} was unable to identify the board and/or microcontroller running "
+        "the {0} platform. Please be sure you have the latest packages running: 'pip3 install "
+        "--upgrade adafruit-blinka adafruit-platformdetect'".format(
+            platform.system(), package[0], package[1]
+        )
+    )
+
 else:
     raise NotImplementedError("Board not supported {}".format(board_id))
 
+if "SCL" in locals() and "SDA" in locals():
 
-def I2C():
-    """The singleton I2C interface"""
-    import busio
+    def I2C():
+        """The singleton I2C interface"""
+        import busio
 
-    return busio.I2C(SCL, SDA)
+        return busio.I2C(SCL, SDA)
 
 
-def SPI():
-    """The singleton SPI interface"""
-    import busio
+if "SCLK" in locals() and "MOSI" in locals() and "MISO" in locals():
 
-    return busio.SPI(SCLK, MOSI, MISO)
+    def SPI():
+        """The singleton SPI interface"""
+        import busio
+
+        return busio.SPI(SCLK, MOSI, MISO)
