@@ -1,19 +1,26 @@
 """Microcontroller pins"""
 
+import time
+
 from adafruit_platformdetect.constants import chips as ap_chip
 from adafruit_blinka import Enum
 from adafruit_blinka.agnostic import board_id, chip_id
 
 
+def delay_us(delay):
+    """Sleep for delay usecs."""
+    time.sleep(delay / 1e6)
+
+
 class Pin(Enum):
     """Reference Pin object"""
 
     def __init__(self, pin_id):
         """Identifier for pin, referencing platform-specific pin id"""
-        self._id = pin_id
+        self.id = pin_id
 
     def __repr__(self):
-        # pylint: disable=import-outside-toplevel
+        # pylint: disable=import-outside-toplevel, cyclic-import
         import board
 
         for key in dir(board):
@@ -21,7 +28,7 @@ class Pin(Enum):
                 return "board.{}".format(key)
         import microcontroller.pin as pin
 
-        # pylint: enable=import-outside-toplevel
+        # pylint: enable=import-outside-toplevel, cyclic-import
 
         for key in dir(pin):
             if getattr(pin, key) is self:
@@ -36,6 +43,8 @@ if chip_id == ap_chip.ESP8266:
     from adafruit_blinka.microcontroller.esp8266 import *
 elif chip_id == ap_chip.STM32F405:
     from adafruit_blinka.microcontroller.stm32.stm32f405 import *
+elif chip_id == ap_chip.RP2040:
+    from adafruit_blinka.microcontroller.rp2040 import *
 elif chip_id == ap_chip.BCM2XXX:
     from adafruit_blinka.microcontroller.bcm283x import *
 elif chip_id == ap_chip.DRA74X:
@@ -44,6 +53,12 @@ elif chip_id == ap_chip.AM33XX:
     from adafruit_blinka.microcontroller.am335x import *
 elif chip_id == ap_chip.SUN8I:
     from adafruit_blinka.microcontroller.allwinner.h3 import *
+elif chip_id == ap_chip.H5:
+    from adafruit_blinka.microcontroller.allwinner.h5.pin import *
+elif chip_id == ap_chip.H6:
+    from adafruit_blinka.microcontroller.allwinner.h6.pin import *
+elif chip_id == ap_chip.H616:
+    from adafruit_blinka.microcontroller.allwinner.h616.pin import *
 elif chip_id == ap_chip.SAMA5:
     from adafruit_blinka.microcontroller.sama5 import *
 elif chip_id == ap_chip.T210:
@@ -68,6 +83,10 @@ elif chip_id == ap_chip.A33:
     from adafruit_blinka.microcontroller.allwinner.a33.pin import *
 elif chip_id == ap_chip.RK3308:
     from adafruit_blinka.microcontroller.rockchip.rk3308.pin import *
+elif chip_id == ap_chip.RK3399:
+    from adafruit_blinka.microcontroller.rockchip.rk3399.pin import *
+elif chip_id == ap_chip.RK3328:
+    from adafruit_blinka.microcontroller.rockchip.rk3328.pin import *
 elif chip_id == ap_chip.H5:
     from adafruit_blinka.microcontroller.allwinner.h5.pin import *
 elif chip_id == ap_chip.IMX8MX:
