@@ -1,8 +1,9 @@
 """
 `neopixel_write` - NeoPixel precision timed writing support
-=================================================
+===========================================================
 
 See `CircuitPython:neopixel_write` in CircuitPython for more details.
+Currently supported on Raspberry Pi only.
 
 * Author(s): ladyada
 """
@@ -13,6 +14,8 @@ from adafruit_blinka.agnostic import detector
 
 if detector.board.any_raspberry_pi:
     from adafruit_blinka.microcontroller.bcm283x import neopixel as _neopixel
+elif detector.board.pico_u2if:
+    from adafruit_blinka.microcontroller.pico_u2if import neopixel as _neopixel
 elif "sphinx" in sys.modules:
     pass
 else:
